This file contains a list with all the contributors to the *grid strategy* project.

Contributors
------------

- Paul Ganssle <paul@ganssle.io>
- Konstantinos Oikonomou <kons.oikonomou@gmail.com>
- Gurnek Singh Mokha <gurnekmokha96@gmail.com>
- Morgan Haworth <morgan123haworth@gmail.com>
- Siping Meng <sipingmeng97@gmail.com>
